@@ -23,11 +23,11 @@
  * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
  * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- *  $Id: movecheck.c,v 1.10 2002/04/17 17:21:07 jdorje Exp $
+ *  $Id: movecheck.c 6293 2004-11-07 05:51:47Z jdorje $
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>			/* Site-specific config */
+#  include <config.h>	/* Site-specific config */
 #endif
 
 #include <stdlib.h>
@@ -37,29 +37,40 @@
 
 #include "cgc.h"
 
-static int valid_knight(struct game *curgame, int fs, int rs, int fd, int rd, int promote);
-static int valid_bishop(struct game *curgame, int fs, int rs, int fd, int rd, int promote);
-static int valid_rook(struct game *curgame, int fs, int rs, int fd, int rd, int promote);
-static int valid_queen(struct game *curgame, int fs, int rs, int fd, int rd, int promote);
-static int valid_king(struct game *curgame, int fs, int rs, int fd, int rd, int promote);
-static int check_castle(struct game *curgame, int fs, int rs, int fd, int rd);
+static int valid_knight(struct game *curgame, int fs, int rs, int fd,
+			int rd, int promote);
+static int valid_bishop(struct game *curgame, int fs, int rs, int fd,
+			int rd, int promote);
+static int valid_rook(struct game *curgame, int fs, int rs, int fd, int rd,
+		      int promote);
+static int valid_queen(struct game *curgame, int fs, int rs, int fd,
+		       int rd, int promote);
+static int valid_king(struct game *curgame, int fs, int rs, int fd, int rd,
+		      int promote);
+static int check_castle(struct game *curgame, int fs, int rs, int fd,
+			int rd);
 static int can_be_occupied(struct game *curgame, int f, int r, int pcol);
-static int check_attackers(struct game *curgame, int f, int r, int *af, int *ar, int pcol, int check_occupied);
+static int check_attackers(struct game *curgame, int f, int r, int *af,
+			   int *ar, int pcol, int check_occupied);
 static int safe_square(struct game *curgame, int f, int r);
 static int safe_from_color(struct game *curgame, int f, int r, int col);
-static int find_attacker(struct game *curgame, int f, int r, int *af, int *ar);
-static int check_knight_attackers(struct game *curgame, int f, int r, int *af, int *ar, int pcol);
-static int valid_pawn(struct game *curgame, int fs, int rs, int fd, int rd, int promote);
+static int find_attacker(struct game *curgame, int f, int r, int *af,
+			 int *ar);
+static int check_knight_attackers(struct game *curgame, int f, int r,
+				  int *af, int *ar, int pcol);
+static int valid_pawn(struct game *curgame, int fs, int rs, int fd, int rd,
+		      int promote);
 static int king_has_move(struct game *curgame, int kf, int kr);
-static int check_rook_moves(piece_t **board, int f, int r);
-static int check_bishop_moves(piece_t **board, int f, int r);
-static int check_knight_moves(piece_t **board, int f, int r);
+static int check_rook_moves(piece_t ** board, int f, int r);
+static int check_bishop_moves(piece_t ** board, int f, int r);
+static int check_knight_moves(piece_t ** board, int f, int r);
 static int can_move(struct game *curgame, int f, int r, int kf, int kr);
 static int onboard(int f, int r);
 static int bishop_type(int f, int r);
 
 int
-cgc_valid_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+cgc_valid_move(struct game *curgame, int fs, int rs, int fd, int rd,
+	       int promote)
 {
 	piece_t actpiece;
 	piece_t tmp;
@@ -68,31 +79,33 @@ cgc_valid_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote
 
 	struct pinfo {
 		int name;
-		int (*cgc_valid_move)(struct game *, int, int, int, int, int);
+		int (*cgc_valid_move) (struct game *, int, int, int, int,
+				       int);
 	} piece[] = {
-		{ KNIGHT, valid_knight },
-		{ BISHOP, valid_bishop },
-		{ ROOK, valid_rook },
-		{ QUEEN, valid_queen },
-		{ KING, valid_king },
-		{ PAWN, valid_pawn },
-		{ 0, NULL }
-	}; 
+		{
+		KNIGHT, valid_knight}, {
+		BISHOP, valid_bishop}, {
+		ROOK, valid_rook}, {
+		QUEEN, valid_queen}, {
+		KING, valid_king}, {
+		PAWN, valid_pawn}, {
+		0, NULL}
+	};
 
 	struct pinfo *cptr;
 
 	/* Basic sanity checks */
 
-	if(!onboard(fs, rs) || !onboard(fd, rd))
+	if (!onboard(fs, rs) || !onboard(fd, rd))
 		return E_BADMOVE;
 
-	if(!curgame->player1 || !curgame->player2)
+	if (!curgame->player1 || !curgame->player2)
 		return E_PLAYERALONE;
 
-	if(color(curgame->board[fs][rs]) != curgame->onmove)
+	if (color(curgame->board[fs][rs]) != curgame->onmove)
 		return E_WRONGCOLOR;
 
-	if(curgame->board[fs][rs] == EMPTY)
+	if (curgame->board[fs][rs] == EMPTY)
 		return E_BADMOVE;
 
 	/*
@@ -102,28 +115,28 @@ cgc_valid_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote
 
 	actpiece = cgc_piece_type(curgame->board[fs][rs]);
 
-	if(fd == fs && rd == rs)
+	if (fd == fs && rd == rs)
 		return E_BADMOVE;
 
-	if(color(curgame->board[fd][rd]) == color(curgame->board[fs][rs]))
-		 return E_BADMOVE;
+	if (color(curgame->board[fd][rd]) == color(curgame->board[fs][rs]))
+		return E_BADMOVE;
 
-	for(cptr = piece; cptr->name; cptr++)
-		if(cptr->name == actpiece)
+	for (cptr = piece; cptr->name; cptr++)
+		if (cptr->name == actpiece)
 			break;
 
 	assert(cptr->name);
 
-	if(!cptr->cgc_valid_move(curgame, fs, rs, fd, rd, promote))
+	if (!cptr->cgc_valid_move(curgame, fs, rs, fd, rd, promote))
 		return E_BADMOVE;
 
 
-	if(curgame->onmove == WHITE) {
-			kf = curgame->wkf;
-			kr = curgame->wkr;
-	} else { 
-			kf = curgame->bkf;
-			kr = curgame->bkr;
+	if (curgame->onmove == WHITE) {
+		kf = curgame->wkf;
+		kr = curgame->wkr;
+	} else {
+		kf = curgame->bkf;
+		kr = curgame->bkr;
 	}
 
 	/* We can't end the move in check. */
@@ -132,7 +145,7 @@ cgc_valid_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote
 	curgame->board[fd][rd] = curgame->board[fs][rs];
 	curgame->board[fs][rs] = EMPTY;
 
-	if(cgc_piece_type(curgame->board[fd][rd]) != KING) {
+	if (cgc_piece_type(curgame->board[fd][rd]) != KING) {
 		retval = safe_square(curgame, kf, kr);
 	} else {
 		retval = safe_square(curgame, fd, rd);
@@ -141,22 +154,23 @@ cgc_valid_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote
 	curgame->board[fs][rs] = curgame->board[fd][rd];
 	curgame->board[fd][rd] = tmp;
 
-	if(!retval)
+	if (!retval)
 		return E_BADMOVE;
 
 	return OK;
 }
 
 int
-cgc_do_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+cgc_do_move(struct game *curgame, int fs, int rs, int fd, int rd,
+	    int promote)
 {
 	piece_t kf, kr;
 	int epossible;
 	int kcastle, qcastle;
 
-	epossible = -1; /* If we aren't replaced, then chance is lost for ep */
+	epossible = -1;	/* If we aren't replaced, then chance is lost for ep */
 
-	if(curgame->onmove == WHITE) {
+	if (curgame->onmove == WHITE) {
 		kcastle = curgame->wkcastle;
 		qcastle = curgame->wqcastle;
 		kf = curgame->wkf;
@@ -171,42 +185,46 @@ cgc_do_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 	/* Point of no return- We're going with it! */
 
 	/* Castling */
-	if(cgc_piece_type(curgame->board[fs][rs]) == KING && abs(fd-fs) > 1) {
-		if(fd == 2) {
+	if (cgc_piece_type(curgame->board[fs][rs]) == KING
+	    && abs(fd - fs) > 1) {
+		if (fd == 2) {
 			curgame->board[3][rd] = (ROOK | curgame->onmove);
 			curgame->board[0][rd] = EMPTY;
 		}
-		if(fd == 6) {
+		if (fd == 6) {
 			curgame->board[5][rd] = (ROOK | curgame->onmove);
 			curgame->board[7][rd] = EMPTY;
 		}
 		kcastle = qcastle = 0;
 	}
 
-	if(cgc_piece_type(curgame->board[fs][rs]) == KING) {
+	if (cgc_piece_type(curgame->board[fs][rs]) == KING) {
 		kf = fd;
 		kr = rd;
 		kcastle = qcastle = 0;
 	}
 
-	if(cgc_piece_type(curgame->board[fs][rs]) == ROOK) {
-		if(fs == 0) qcastle = 0;
-		if(fs == 7) kcastle = 0;
+	if (cgc_piece_type(curgame->board[fs][rs]) == ROOK) {
+		if (fs == 0)
+			qcastle = 0;
+		if (fs == 7)
+			kcastle = 0;
 	}
 
-	if(cgc_piece_type(curgame->board[fs][rs]) == PAWN) {
-	
+	if (cgc_piece_type(curgame->board[fs][rs]) == PAWN) {
+
 		/* Promotion */
-		if(color(curgame->board[fs][rs]) == WHITE && rs == 6) { 
+		if (color(curgame->board[fs][rs]) == WHITE && rs == 6) {
 			curgame->board[fs][rs] = (promote | WHITE);
 			rd = 7;
-		} else if(color(curgame->board[fs][rs]) == BLACK && rs == 1) {
+		} else if (color(curgame->board[fs][rs]) == BLACK
+			   && rs == 1) {
 			curgame->board[fs][rs] = (promote | BLACK);
 			rd = 0;
 		}
 
 		/* Check to see if we're endangered for ep */
-		if(abs(rs-rd) > 1) /* They can do ep! */
+		if (abs(rs - rd) > 1)	/* They can do ep! */
 			epossible = fd;
 
 		/* Check to see if we're doing ep
@@ -215,9 +233,9 @@ cgc_do_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 		 * to be the one we're caputring and the other
 		 * really should be (or else uh-oh) empty :)
 		 */
-		if(curgame->board[fd][rd] == EMPTY && fd != fs) {
-			curgame->board[fd][rd-1] = EMPTY;
-			curgame->board[fd][rd+1] = EMPTY;
+		if (curgame->board[fd][rd] == EMPTY && fd != fs) {
+			curgame->board[fd][rd - 1] = EMPTY;
+			curgame->board[fd][rd + 1] = EMPTY;
 		}
 	}
 
@@ -228,7 +246,7 @@ cgc_do_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 
 	curgame->epossible = epossible;
 
-	if(curgame->onmove == WHITE) {
+	if (curgame->onmove == WHITE) {
 		curgame->wkf = kf;
 		curgame->wkr = kr;
 		curgame->wkcastle = kcastle;
@@ -246,14 +264,17 @@ cgc_do_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 }
 
 static int
-valid_knight(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+valid_knight(struct game *curgame, int fs, int rs, int fd, int rd,
+	     int promote)
 {
-	switch(abs(rs-rd)) {
+	switch (abs(rs - rd)) {
 	case 2:
-		if(abs(fs-fd) == 1) return VALID;
+		if (abs(fs - fd) == 1)
+			return VALID;
 		break;
 	case 1:
-		if(abs(fs-fd) == 2) return VALID;
+		if (abs(fs - fd) == 2)
+			return VALID;
 		break;
 	}
 
@@ -261,23 +282,27 @@ valid_knight(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 }
 
 static int
-valid_bishop(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+valid_bishop(struct game *curgame, int fs, int rs, int fd, int rd,
+	     int promote)
 {
 	int cf, cr;
 	int diag = 0;
 
-	if(abs(fd-fs) != abs(rd-rs))
-		 return INVALID;  /* Capture the way off ones */
+	if (abs(fd - fs) != abs(rd - rs))
+		return INVALID;	/* Capture the way off ones */
 
-	if(fs > fd && rs > rd) diag = 3;
-	if(fs > fd && rs < rd) diag = 2;
-	if(fs < fd && rs > rd) diag = 1;
+	if (fs > fd && rs > rd)
+		diag = 3;
+	if (fs > fd && rs < rd)
+		diag = 2;
+	if (fs < fd && rs > rd)
+		diag = 1;
 
 	cf = fs;
 	cr = rs;
-		
-	for(;;) {
-		switch(diag) {
+
+	for (;;) {
+		switch (diag) {
 		case 0:
 			++cf, ++cr;
 			break;
@@ -291,45 +316,47 @@ valid_bishop(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 			--cf, --cr;
 			break;
 		}
-			
-		if(!onboard(cf,cr))
-			return INVALID; /* Off the board, fail */
-			
-		if(cf == fd && cr == rd)
-			return VALID; /* We're here! pass */
 
-		if(curgame->board[cf][cr] != EMPTY)
-			break; /* Walked into another piece, fail */
- 	}
+		if (!onboard(cf, cr))
+			return INVALID;	/* Off the board, fail */
+
+		if (cf == fd && cr == rd)
+			return VALID;	/* We're here! pass */
+
+		if (curgame->board[cf][cr] != EMPTY)
+			break;	/* Walked into another piece, fail */
+	}
 
 	return INVALID;
 }
 
 static int
-valid_rook(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+valid_rook(struct game *curgame, int fs, int rs, int fd, int rd,
+	   int promote)
 {
 	int cf, cr;
 	int diag = 0;
 
-	if(rs != rd && fs != fd) return INVALID;  /* capture the way off ones */
+	if (rs != rd && fs != fd)
+		return INVALID;	/* capture the way off ones */
 
-	if(fd < fs) /* If we're headed to the left */
+	if (fd < fs)	/* If we're headed to the left */
 		diag = 1;
 
-	if(rd < rs) /* If we're going down */
+	if (rd < rs)	/* If we're going down */
 		diag = 3;
 
-	if(fd > fs) /* Going right */
+	if (fd > fs)	/* Going right */
 		diag = 0;
 
-	if(rd > rs) /* Going up */
+	if (rd > rs)	/* Going up */
 		diag = 2;
 
 	cf = fs;
 	cr = rs;
-	
-	for(;;) {
-		switch(diag) {
+
+	for (;;) {
+		switch (diag) {
 		case 0:
 			++cf;
 			break;
@@ -343,35 +370,42 @@ valid_rook(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 			--cr;
 			break;
 		}
-		if(!onboard(cf, cr)) break;
-		
-		if(cf == fd && cr == rd) return VALID;
-		if(curgame->board[cf][cr] != EMPTY) break;
+		if (!onboard(cf, cr))
+			break;
+
+		if (cf == fd && cr == rd)
+			return VALID;
+		if (curgame->board[cf][cr] != EMPTY)
+			break;
 	}
 
 	return INVALID;
 }
 
 static int
-valid_queen(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+valid_queen(struct game *curgame, int fs, int rs, int fd, int rd,
+	    int promote)
 {
-	if(valid_rook(curgame, fs, rs, fd, rd, promote)) return VALID;
-	if(valid_bishop(curgame, fs, rs, fd, rd, promote)) return VALID; 
+	if (valid_rook(curgame, fs, rs, fd, rd, promote))
+		return VALID;
+	if (valid_bishop(curgame, fs, rs, fd, rd, promote))
+		return VALID;
 	return INVALID;
 }
 
 static int
-valid_king(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+valid_king(struct game *curgame, int fs, int rs, int fd, int rd,
+	   int promote)
 {
 
 	int enemy;
 
 	enemy = curgame->onmove ? BLACK : WHITE;
 
-	if(abs(rs-rd) <= 1 && abs(fs-fd) <= 1)
+	if (abs(rs - rd) <= 1 && abs(fs - fd) <= 1)
 		return VALID;
 
-	if(abs(rs-rd) == 0 && (abs(fs-fd) == 2 || abs(fs-fd) == 3))
+	if (abs(rs - rd) == 0 && (abs(fs - fd) == 2 || abs(fs - fd) == 3))
 		return check_castle(curgame, fs, rs, fd, rd);
 
 	return INVALID;
@@ -381,35 +415,40 @@ static int
 check_castle(struct game *curgame, int fs, int rs, int fd, int rd)
 {
 	int enemy;
-	
+
 	enemy = curgame->onmove ? BLACK : WHITE;
 
-	if(curgame->onmove == WHITE && rd != 0) return INVALID;
-	if(curgame->onmove == BLACK && rd != 7) return INVALID;
-	if(curgame->board[(fd+fs)/2][rd] != EMPTY) return INVALID;
-	if(curgame->board[fd][rd] != EMPTY) return INVALID; 
+	if (curgame->onmove == WHITE && rd != 0)
+		return INVALID;
+	if (curgame->onmove == BLACK && rd != 7)
+		return INVALID;
+	if (curgame->board[(fd + fs) / 2][rd] != EMPTY)
+		return INVALID;
+	if (curgame->board[fd][rd] != EMPTY)
+		return INVALID;
 
-	if(!safe_from_color(curgame, (fd+fs)/2, rd, enemy)) return INVALID;
-	if(!safe_from_color(curgame, fs, rs, enemy)) return INVALID;
+	if (!safe_from_color(curgame, (fd + fs) / 2, rd, enemy))
+		return INVALID;
+	if (!safe_from_color(curgame, fs, rs, enemy))
+		return INVALID;
 
-	switch(fd) {
+	switch (fd) {
 	case 2:
-		if(curgame->onmove == WHITE && curgame->wqcastle)
+		if (curgame->onmove == WHITE && curgame->wqcastle)
 			return VALID;
-		if(curgame->onmove == BLACK && curgame->bqcastle)
+		if (curgame->onmove == BLACK && curgame->bqcastle)
 			return VALID;
 	case 6:
-		if(curgame->onmove == WHITE && curgame->wkcastle)
+		if (curgame->onmove == WHITE && curgame->wkcastle)
 			return VALID;
-		if(curgame->onmove == BLACK && curgame->bkcastle)
+		if (curgame->onmove == BLACK && curgame->bkcastle)
 			return VALID;
 	}
-	
+
 	return INVALID;
 }
 
-static int
-can_be_occupied(struct game *curgame, int f, int r, int pcol)
+static int can_be_occupied(struct game *curgame, int f, int r, int pcol)
 {
 	int af;
 	int ar;
@@ -417,7 +456,7 @@ can_be_occupied(struct game *curgame, int f, int r, int pcol)
 	int kf, kr;
 	int tmp;
 
-	if(curgame->onmove == WHITE) {
+	if (curgame->onmove == WHITE) {
 		kf = curgame->wkf;
 		kr = curgame->wkr;
 	} else {
@@ -428,13 +467,13 @@ can_be_occupied(struct game *curgame, int f, int r, int pcol)
 	rval = check_attackers(curgame, f, r, &af, &ar, pcol, 1);
 
 	curgame->board[kf][kr] = (KING | pcol);
- 
-	if(rval == VALID) {
+
+	if (rval == VALID) {
 		tmp = curgame->board[af][ar];
 		curgame->board[f][r] = tmp;
 		curgame->board[af][ar] = EMPTY;
-		
-		if(safe_square(curgame, kf, kr)) {
+
+		if (safe_square(curgame, kf, kr)) {
 			curgame->board[af][ar] = tmp;
 			curgame->board[kf][kr] = EMPTY;
 			curgame->board[f][r] = EMPTY;
@@ -443,102 +482,102 @@ can_be_occupied(struct game *curgame, int f, int r, int pcol)
 		curgame->board[af][ar] = tmp;
 	}
 
-	curgame->board[f][r] = EMPTY;	
+	curgame->board[f][r] = EMPTY;
 	curgame->board[kf][kr] = EMPTY;
 
 	return INVALID;
 }
- 
+
 
 /* Can a piece belonging to pcol move to the given square? */
 static int
-check_attackers(struct game *curgame, int f, int r, int *af, int *ar, int pcol,
-		int check_occupied)
+check_attackers(struct game *curgame, int f, int r, int *af, int *ar,
+		int pcol, int check_occupied)
 {
-	int cf, cr; /* The file and rank we look for the attacker in */
-	int diag; /* Which of 8 diagonals we are operating on */
-	int dist; /* How far are we from origin? */
-	piece_t tmp; /* We could be checking an empty sq */
+	int cf, cr;		/* The file and rank we look for the attacker in */
+	int diag;		/* Which of 8 diagonals we are operating on */
+	int dist;		/* How far are we from origin? */
+	piece_t tmp;		/* We could be checking an empty sq */
 
 	dist = diag = 0;
 
 	tmp = curgame->board[f][r];
-	
-	if(check_knight_attackers(curgame, f, r, af, ar, pcol))
+
+	if (check_knight_attackers(curgame, f, r, af, ar, pcol))
 		return VALID;
 
-	for(;;) {
+	for (;;) {
 		cf = f;
 		cr = r;
 
-		for(;;) {
-			switch(diag) {
+		for (;;) {
+			switch (diag) {
 			case 0:
-				++cf, ++cr; /* up right */
+				++cf, ++cr;	/* up right */
 				break;
 			case 1:
-				++cf, --cr; /* down right */
+				++cf, --cr;	/* down right */
 				break;
 			case 2:
-				--cf, ++cr; /* up left */ 
+				--cf, ++cr;	/* up left */
 				break;
 			case 3:
-				--cf, --cr; /* down left */
+				--cf, --cr;	/* down left */
 				break;
 			case 4:
-				++cf; /* right */
+				++cf;	/* right */
 				break;
 			case 5:
-				--cf; /* left */
+				--cf;	/* left */
 				break;
-			case 6: 
-				++cr; /* up */
+			case 6:
+				++cr;	/* up */
 				break;
 			case 7:
-				--cr; /* down */
+				--cr;	/* down */
 				break;
 			}
 
-			if(af != NULL && ar != NULL)
+			if (af != NULL && ar != NULL)
 				*af = cf, *ar = cr;
 
 			/* If we're off the board, try another diag */
-			if(!onboard(cf, cr))
+			if (!onboard(cf, cr))
 				break;
 
 			++dist;
 
 			/* Our own piece can't hurt us */
-			if(curgame->board[cf][cr] != EMPTY)
-				if(color(curgame->board[cf][cr]) != pcol)
+			if (curgame->board[cf][cr] != EMPTY)
+				if (color(curgame->board[cf][cr]) != pcol)
 					break;
 
 			/* Stop for blockers */
-			if(curgame->board[cf][cr] == BLOCKER) 
+			if (curgame->board[cf][cr] == BLOCKER)
 				break;
 
-			switch(curgame->board[cf][cr]) {
-			case W_QUEEN:  
+			switch (curgame->board[cf][cr]) {
+			case W_QUEEN:
 			case B_QUEEN:
 				return VALID;
 				break;
 			case B_PAWN:
-				if(!check_occupied)
-					if(curgame->board[f][r] == EMPTY)
+				if (!check_occupied)
+					if (curgame->board[f][r] == EMPTY)
 						curgame->board[f][r] = 60;
 
-				if(valid_pawn(curgame, cf, cr, f, r, 0)) {
+				if (valid_pawn(curgame, cf, cr, f, r, 0)) {
 					curgame->board[f][r] = tmp;
 					return VALID;
 				}
 				curgame->board[f][r] = tmp;
 				break;
 			case W_PAWN:
-				if(!check_occupied)
-					if(curgame->board[f][r] == EMPTY)
+				if (!check_occupied)
+					if (curgame->board[f][r] == EMPTY)
 						curgame->board[f][r] = 50;
 
-				if(valid_pawn(curgame, cf, cr, f, r, 0)) {
+				if (valid_pawn(curgame, cf, cr, f, r, 0)) {
 					curgame->board[f][r] = tmp;
 					return VALID;
 				}
@@ -546,26 +585,29 @@ check_attackers(struct game *curgame, int f, int r, int *af, int *ar, int pcol,
 				break;
 			case W_KING:
 			case B_KING:
-				if(dist == 1) return VALID;
+				if (dist == 1)
+					return VALID;
 				break;
 			case W_BISHOP:
 			case B_BISHOP:
-				if(diag <= 3) return VALID;
+				if (diag <= 3)
+					return VALID;
 				break;
 			case W_ROOK:
 			case B_ROOK:
-				if(diag >= 4) return VALID;
+				if (diag >= 4)
+					return VALID;
 				break;
 			}
-		
-			if(curgame->board[cf][cr] != EMPTY)
+
+			if (curgame->board[cf][cr] != EMPTY)
 				break;
 		}
 
-		if(++diag > 7)
+		if (++diag > 7)
 			break;
 
-		dist = 0; /* here we go again */
+		dist = 0;	/* here we go again */
 	}
 
 	return INVALID;
@@ -573,8 +615,7 @@ check_attackers(struct game *curgame, int f, int r, int *af, int *ar, int pcol,
 
 
 /* is square safe from enemy?  non-zero if true, zero if false */
-static int
-safe_square(struct game *curgame, int f, int r)
+static int safe_square(struct game *curgame, int f, int r)
 {
 	int enemy;
 
@@ -587,16 +628,15 @@ safe_square(struct game *curgame, int f, int r)
  * but it is easier to parse than check_attackers itself.
  */
 
-static int
-safe_from_color(struct game *curgame, int f, int r, int col)
+static int safe_from_color(struct game *curgame, int f, int r, int col)
 {
-	if(check_attackers(curgame, f, r, NULL, NULL, col, 0))
+	if (check_attackers(curgame, f, r, NULL, NULL, col, 0))
 		return INVALID;
 
 	return VALID;
 }
 
-/* same as safe_square but don't discard af/ar */ 
+/* same as safe_square but don't discard af/ar */
 static int
 find_attacker(struct game *curgame, int f, int r, int *af, int *ar)
 {
@@ -604,15 +644,15 @@ find_attacker(struct game *curgame, int f, int r, int *af, int *ar)
 
 	enemy = (color(curgame->board[f][r]) ? BLACK : WHITE);
 
-	if(check_attackers(curgame, f, r, af, ar, enemy, 0))
-		return VALID; /* Found the attacker */
+	if (check_attackers(curgame, f, r, af, ar, enemy, 0))
+		return VALID;	/* Found the attacker */
 
-	return INVALID; /* No attacker, it's safe */
+	return INVALID;	/* No attacker, it's safe */
 }
 
 static int
 check_knight_attackers(struct game *curgame, int f, int r, int *af,
-                       int *ar, int pcol)
+		       int *ar, int pcol)
 {
 	int cf;
 	int cr;
@@ -621,10 +661,10 @@ check_knight_attackers(struct game *curgame, int f, int r, int *af,
 
 	enemy = KNIGHT | pcol;
 
-	for(line = 0; line < 8 ; ++line) {
+	for (line = 0; line < 8; ++line) {
 		cf = f;
-		cr = r;	
-		switch(line) {
+		cr = r;
+		switch (line) {
 		case 0:
 			cf += 2;
 			cr += 1;
@@ -659,11 +699,11 @@ check_knight_attackers(struct game *curgame, int f, int r, int *af,
 			break;
 		}
 
-		if(!onboard(cf, cr))
+		if (!onboard(cf, cr))
 			continue;
 
-		if(curgame->board[cf][cr] == enemy) {
-			if(af != NULL && ar != NULL) {
+		if (curgame->board[cf][cr] == enemy) {
+			if (af != NULL && ar != NULL) {
 				*af = cf;
 				*ar = cr;
 			}
@@ -675,74 +715,83 @@ check_knight_attackers(struct game *curgame, int f, int r, int *af,
 }
 
 static int
-valid_pawn(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+valid_pawn(struct game *curgame, int fs, int rs, int fd, int rd,
+	   int promote)
 {
-	switch(curgame->board[fs][rs]) {
+	switch (curgame->board[fs][rs]) {
 	case W_PAWN:
 		/* Basic sanity checks */
 
 		/* We must be going forward */
-		if(rd <= rs) return INVALID;
+		if (rd <= rs)
+			return INVALID;
 
 		/* Can never move more than 1 unit diagonally */
-		if(abs(fd-fs) > 1) return INVALID;
+		if (abs(fd - fs) > 1)
+			return INVALID;
 
 		/* Cannot walk into a piece */
-		if(curgame->board[fd][rd] != EMPTY && fd == fs) return INVALID;
+		if (curgame->board[fd][rd] != EMPTY && fd == fs)
+			return INVALID;
 
 
 		/* Check for non-capture pawn pushes */
-		if(fd == fs) {
+		if (fd == fs) {
 
 			/* Look for an inital 2 space advancement */
-			if(rs == 1 && curgame->board[fd][rs + 1] == EMPTY)
-				if(abs(rd-rs) == 2)
-					 return VALID;
+			if (rs == 1 && curgame->board[fd][rs + 1] == EMPTY)
+				if (abs(rd - rs) == 2)
+					return VALID;
 
 			/* Check for a simple pawn push */
-			if(abs(rd - rs) == 1)
+			if (abs(rd - rs) == 1)
 				return VALID;
 
 			return INVALID;
 		}
 
 
-		if(abs(fd-fs) != 1)
+		if (abs(fd - fs) != 1)
 			return INVALID;
 
 		/* Check our diagonal moves, ep and attack */
 
 		/* No diagonal move traverses more than one rank */
-		if(abs(rd - rs) != 1)
+		if (abs(rd - rs) != 1)
 			return INVALID;
- 
-		if(rd == 5 && fd == curgame->epossible) return VALID; /*ep*/
-		if(curgame->board[fd][rd] != EMPTY) return VALID; /* attack */
+
+		if (rd == 5 && fd == curgame->epossible)
+			return VALID;	/*ep */
+		if (curgame->board[fd][rd] != EMPTY)
+			return VALID;	/* attack */
 
 		break;
 	case B_PAWN:
 		/* Basic sanity checks */
 
 		/* Must be going forward */
-		if(rd >= rs) return INVALID;
+		if (rd >= rs)
+			return INVALID;
 
 		/* Can never move more than one diag */
-		if(abs(fd-fs) > 1) return INVALID;
+		if (abs(fd - fs) > 1)
+			return INVALID;
 
 		/* Can't walk forward into a piece */
-		if(curgame->board[fd][rd] != EMPTY && fd == fs) return INVALID;
+		if (curgame->board[fd][rd] != EMPTY && fd == fs)
+			return INVALID;
 
 
 		/* Check for non-capture pawn pushes */
-		if(fd == fs) {
+		if (fd == fs) {
 
 			/* Check for inital 2 space pawn movement */
-			if(rs == 6 && curgame->board[fd][rs - 1] == EMPTY)
-				if(abs(rd-rs) == 2)
-				 	return VALID;
+			if (rs == 6 && curgame->board[fd][rs - 1] == EMPTY)
+				if (abs(rd - rs) == 2)
+					return VALID;
 
 			/* Check for a simple pawn push */
-			if(abs(rd - rs) == 1)
+			if (abs(rd - rs) == 1)
 				return VALID;
 
 			return INVALID;
@@ -752,25 +801,29 @@ valid_pawn(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
 		/* Check our diagonal moves, ep and attack */
 
 		/* No diagonal move goes moves more than one rank */
-		if(abs(rd - rs) != 1) return INVALID;
- 
-		if(rd == 2 && fd == curgame->epossible) return VALID; /*ep*/
-		if(curgame->board[fd][rd] != EMPTY) return VALID; /* attack */
+		if (abs(rd - rs) != 1)
+			return INVALID;
+
+		if (rd == 2 && fd == curgame->epossible)
+			return VALID;	/*ep */
+		if (curgame->board[fd][rd] != EMPTY)
+			return VALID;	/* attack */
 
 		break;
 	}
 
 	return INVALID;
- 
+
 
 }
 
 int
-cgc_register_move(struct game *curgame, int fs, int rs, int fd, int rd, int promote)
+cgc_register_move(struct game *curgame, int fs, int rs, int fd, int rd,
+		  int promote)
 {
 	struct move *latest;
 	struct move *walker;
-	int irrev = 0; /* is the move irreversable? */
+	int irrev = 0;		/* is the move irreversable? */
 
 	latest = malloc(sizeof(struct move));
 
@@ -781,21 +834,21 @@ cgc_register_move(struct game *curgame, int fs, int rs, int fd, int rd, int prom
 	latest->promote = promote;
 
 	/* All captures are irreversable */
-	if(curgame->board[fd][rd] != EMPTY)
+	if (curgame->board[fd][rd] != EMPTY)
 		irrev = 1;
 
 	/* All pawn movements are irreversable */
-	if(cgc_piece_type(curgame->board[fs][rs]) == PAWN)
+	if (cgc_piece_type(curgame->board[fs][rs]) == PAWN)
 		irrev = 1;
 
 	latest->captured = cgc_piece_type(curgame->board[fd][rd]);
 
-	if(curgame->movelist == NULL) { /* If first move */
+	if (curgame->movelist == NULL) {	/* If first move */
 		latest->next = latest->prev = NULL;
 		curgame->movelist = latest;
 	} else {
-	 	for(walker = curgame->movelist; walker->next ; walker = walker->next)
-			;
+		for (walker = curgame->movelist; walker->next;
+		     walker = walker->next);
 
 		/* walker is now the last move */
 
@@ -805,7 +858,7 @@ cgc_register_move(struct game *curgame, int fs, int rs, int fd, int rd, int prom
 
 	}
 
-	if(irrev) {
+	if (irrev) {
 		cgc_free_postab(curgame->postab);
 		curgame->hmcount = 0;
 	}
@@ -813,12 +866,11 @@ cgc_register_move(struct game *curgame, int fs, int rs, int fd, int rd, int prom
 	return 0;
 }
 
-int
-cgc_check_state(struct game *curgame, int kf, int kr)
+int cgc_check_state(struct game *curgame, int kf, int kr)
 {
 
 	int cf, cr;
-	int af, ar; /* Attacker's file and rank */
+	int af, ar;		/* Attacker's file and rank */
 	int diag = -1;
 	int status = SAFE;
 	piece_t **board;
@@ -826,13 +878,13 @@ cgc_check_state(struct game *curgame, int kf, int kr)
 
 	board = curgame->board;
 
-	if(find_attacker(curgame, kf, kr, &af, &ar)) { /* Check */
+	if (find_attacker(curgame, kf, kr, &af, &ar)) {	/* Check */
 		status = CHECK;
 	} else {
 		return SAFE;
 	}
 
-	if(king_has_move(curgame, kf, kr))
+	if (king_has_move(curgame, kf, kr))
 		return CHECK;
 
 	/*
@@ -851,13 +903,13 @@ cgc_check_state(struct game *curgame, int kf, int kr)
 	tmp = board[af][ar];
 	board[af][ar] = BISHOP | color(board[kf][kr]);
 
-	if(!safe_square(curgame, kf, kr)) { /* Still not safe, two attacker */
+	if (!safe_square(curgame, kf, kr)) {	/* Still not safe, two attacker */
 		board[af][ar] = tmp;
 		return MATE;
 	}
 
 	board[af][ar] = tmp;
- 
+
 	/*
 	 * We now see if we can capture the attacker.  If
 	 * we can, we see if that removes the king from 
@@ -865,13 +917,13 @@ cgc_check_state(struct game *curgame, int kf, int kr)
 	 * two attackers, in which case there is mate.
 	 * If there's only one attacker, and we can't
 	 * capture it, we have to continue on to see
- 	 * if there can be an interposition.
+	 * if there can be an interposition.
 	 */
 
 	tmp = board[kf][kr];
 	board[kf][kr] = BLOCKER;
 
-	if(!safe_square(curgame, af, ar)) { /* we can capture */
+	if (!safe_square(curgame, af, ar)) {	/* we can capture */
 		board[kf][kr] = tmp;
 		return CHECK;
 	}
@@ -887,18 +939,26 @@ cgc_check_state(struct game *curgame, int kf, int kr)
 	 * sure it's not a knight, because if it is, we're dead.
 	 */
 
-	if(cgc_piece_type(board[af][ar]) == KNIGHT)
+	if (cgc_piece_type(board[af][ar]) == KNIGHT)
 		return MATE;
 
-	if(kf > af && kr > ar) diag = 0;
-	if(kf > af && kr < ar) diag = 1;
-	if(kf < af && kr > ar) diag = 2;
-	if(kf < af && kr < ar) diag = 3;
-	if(kf > af && kr == ar) diag = 4;
-	if(kf < af && kr == ar) diag = 5;
-	if(kf == af && kr < ar) diag = 6;
-	if(kf == af && kr > ar) diag = 7;
-	
+	if (kf > af && kr > ar)
+		diag = 0;
+	if (kf > af && kr < ar)
+		diag = 1;
+	if (kf < af && kr > ar)
+		diag = 2;
+	if (kf < af && kr < ar)
+		diag = 3;
+	if (kf > af && kr == ar)
+		diag = 4;
+	if (kf < af && kr == ar)
+		diag = 5;
+	if (kf == af && kr < ar)
+		diag = 6;
+	if (kf == af && kr > ar)
+		diag = 7;
+
 	ASSERT(diag != -1);
 
 
@@ -911,53 +971,52 @@ cgc_check_state(struct game *curgame, int kf, int kr)
 	 * him back on later.
 	 */
 	tmp = board[kf][kr];
-	board[kf][kr] = EMPTY; 
+	board[kf][kr] = EMPTY;
 
-	for(;;) {
-		switch(diag) {
+	for (;;) {
+		switch (diag) {
 		case 0:
-			--cf, --cr; /* down left */
+			--cf, --cr;	/* down left */
 			break;
 		case 1:
-			--cf, ++cr; /* up left */
+			--cf, ++cr;	/* up left */
 			break;
 		case 2:
-			++cf, --cr; /* down right */ 
+			++cf, --cr;	/* down right */
 			break;
 		case 3:
-			++cf, ++cr; /* up right */
+			++cf, ++cr;	/* up right */
 			break;
 		case 4:
-			--cf; /* left */
+			--cf;	/* left */
 			break;
 		case 5:
-			++cf; /* right */
+			++cf;	/* right */
 			break;
-		case 6: 
-			++cr; /* up */
+		case 6:
+			++cr;	/* up */
 			break;
 		case 7:
-			--cr; /* down */
+			--cr;	/* down */
 			break;
 		}
 
-		if(cf == af && cr == ar) {
+		if (cf == af && cr == ar) {
 			status = MATE;
 			break;
 		}
 
-		if(can_be_occupied(curgame, cf, cr, color(tmp))) {
+		if (can_be_occupied(curgame, cf, cr, color(tmp))) {
 			status = CHECK;
 			break;
 		}
 	}
-	
+
 	board[kf][kr] = tmp;
 	return status;
 }
 
-static int
-king_has_move(struct game *curgame, int kf, int kr)
+static int king_has_move(struct game *curgame, int kf, int kr)
 {
 	int cf, cr;
 	int enemy;
@@ -971,14 +1030,14 @@ king_has_move(struct game *curgame, int kf, int kr)
 
 	tmp = curgame->board[kf][kr];
 	curgame->board[kf][kr] = EMPTY;
- 
+
 	enemy = color(tmp) ? BLACK : WHITE;
 
-	for(direction = 0;direction <= 7; ++direction) {
+	for (direction = 0; direction <= 7; ++direction) {
 		cf = kf;
 		cr = kr;
 
-		switch(direction) {
+		switch (direction) {
 		case 0:
 			++cf;
 			break;
@@ -1009,14 +1068,14 @@ king_has_move(struct game *curgame, int kf, int kr)
 			break;
 		}
 
-		if(!onboard(cf, cr))
+		if (!onboard(cf, cr))
 			continue;
 
 		/* We can't have a valid move into friendly piece */
-		if(color(curgame->board[cf][cr]) == color(tmp))
+		if (color(curgame->board[cf][cr]) == color(tmp))
 			continue;
 
-		if(safe_from_color(curgame, cf, cr, enemy)) {
+		if (safe_from_color(curgame, cf, cr, enemy)) {
 			curgame->board[kf][kr] = tmp;
 			return VALID;
 		}
@@ -1027,8 +1086,7 @@ king_has_move(struct game *curgame, int kf, int kr)
 
 }
 
-int
-cgc_is_stale(struct game *curgame, int kf, int kr)
+int cgc_is_stale(struct game *curgame, int kf, int kr)
 {
 	int cf, cr;
 	piece_t **board;
@@ -1036,59 +1094,59 @@ cgc_is_stale(struct game *curgame, int kf, int kr)
 	board = curgame->board;
 	cf = cr = 0;
 
-	if(king_has_move(curgame, kf, kr))
+	if (king_has_move(curgame, kf, kr))
 		return INVALID;
 
-	for(cf = 0; cf < 8 ; ++cf) {
-		for(cr = 0; cr < 8; ++cr) {
+	for (cf = 0; cf < 8; ++cf) {
+		for (cr = 0; cr < 8; ++cr) {
 
 			/* filter out pieces not on the board */
-			if(!onboard(cf, cr))
+			if (!onboard(cf, cr))
 				continue;
 
 			/*
 			 * we've checked this
 			 * in king_has_move
 			 */
-			if(cgc_piece_type(board[cf][cr]) == KING)
+			if (cgc_piece_type(board[cf][cr]) == KING)
 				continue;
 
 			/* Don't check empties */
-			if(board[cf][cr] == EMPTY)
+			if (board[cf][cr] == EMPTY)
 				continue;
 
 			/* Filter out the enemy's pieces */
-			if(color(board[cf][cr]) != color(board[kf][kr]))
+			if (color(board[cf][cr]) != color(board[kf][kr]))
 				continue;
 
 			/* Filter out pinned pieces */
-			if(!can_move(curgame, cf, cr, kf, kr))
+			if (!can_move(curgame, cf, cr, kf, kr))
 				continue;
-				
-			switch(cgc_piece_type(board[cf][cr])) {
+
+			switch (cgc_piece_type(board[cf][cr])) {
 			case BISHOP:
-				if(check_bishop_moves(board, cf, cr))
+				if (check_bishop_moves(board, cf, cr))
 					return INVALID;
 				break;
 			case KNIGHT:
-				if(check_knight_moves(board, cf, cr))
+				if (check_knight_moves(board, cf, cr))
 					return INVALID;
 				break;
 			case PAWN:
-				if(color(board[cf][cr]) == WHITE) {
-					if(board[cf][cr+1] == EMPTY)
-						return INVALID;
-				} else  if(board[cf][cr-1] == EMPTY)
+				if (color(board[cf][cr]) == WHITE) {
+					if (board[cf][cr + 1] == EMPTY)
 						return INVALID;
+				} else if (board[cf][cr - 1] == EMPTY)
+					return INVALID;
 				break;
 			case ROOK:
-				if(check_rook_moves(board, cf, cr))
+				if (check_rook_moves(board, cf, cr))
 					break;
 				break;
 			case QUEEN:
-				if(check_rook_moves(board, cf, cr))
+				if (check_rook_moves(board, cf, cr))
 					return INVALID;
-				if(check_bishop_moves(board, cf, cr))
+				if (check_bishop_moves(board, cf, cr))
 					return INVALID;
 				break;
 			}
@@ -1098,18 +1156,17 @@ cgc_is_stale(struct game *curgame, int kf, int kr)
 	return INVALID;
 }
 
-static int
-check_rook_moves(piece_t **board, int f, int r)
+static int check_rook_moves(piece_t ** board, int f, int r)
 {
 	int diag;
 	int cf, cr;
 
-	
-	for(diag = 0; diag < 4 ; ++diag) {
+
+	for (diag = 0; diag < 4; ++diag) {
 		cf = f;
 		cr = r;
-			
-		switch(diag) {
+
+		switch (diag) {
 		case 0:
 			++cf;
 			break;
@@ -1124,12 +1181,12 @@ check_rook_moves(piece_t **board, int f, int r)
 			break;
 		}
 
-		if(!onboard(cf,cr))
+		if (!onboard(cf, cr))
 			break;
- 
-		if(color(board[cf][cr]) == color(board[f][r]))
+
+		if (color(board[cf][cr]) == color(board[f][r]))
 			break;
-	
+
 		return VALID;
 
 	}
@@ -1138,18 +1195,17 @@ check_rook_moves(piece_t **board, int f, int r)
 }
 
 
-static int
-check_bishop_moves(piece_t **board, int f, int r)
+static int check_bishop_moves(piece_t ** board, int f, int r)
 {
 	int diag;
 	int cf, cr;
 
-	
-	for(diag = 0; diag < 4 ; ++diag) {
+
+	for (diag = 0; diag < 4; ++diag) {
 		cf = f;
 		cr = r;
-			
-		switch(diag) {
+
+		switch (diag) {
 		case 0:
 			++cf;
 			--cr;
@@ -1168,9 +1224,9 @@ check_bishop_moves(piece_t **board, int f, int r)
 			break;
 		}
 
-		if(color(board[cf][cr]) == color(board[f][r]))
+		if (color(board[cf][cr]) == color(board[f][r]))
 			break;
-	
+
 		return VALID;
 
 	}
@@ -1178,8 +1234,7 @@ check_bishop_moves(piece_t **board, int f, int r)
 	return INVALID;
 }
 
-int
-cgc_has_sufficient(game_t *curgame, int ocolor)
+int cgc_has_sufficient(game_t * curgame, int ocolor)
 {
 	int f, r;
 	int o_knight = 0;
@@ -1187,29 +1242,29 @@ cgc_has_sufficient(game_t *curgame, int ocolor)
 	int o_dbishop, o_lbishop;
 
 	o_dbishop = o_lbishop = e_dbishop = e_lbishop = 0;
-	
-	for(f = 0 ; f < 8 ; ++f) {
-		for(r = 0 ; r < 8 ; ++r) {
-			if(curgame->board[f][r] == EMPTY)
+
+	for (f = 0; f < 8; ++f) {
+		for (r = 0; r < 8; ++r) {
+			if (curgame->board[f][r] == EMPTY)
 				continue;
-			if(color(curgame->board[f][r]) != ocolor &&
+			if (color(curgame->board[f][r]) != ocolor &&
 			    cgc_piece_type(curgame->board[f][r]) != BISHOP)
 				continue;
-			
-			switch(cgc_piece_type(curgame->board[f][r])) {
+
+			switch (cgc_piece_type(curgame->board[f][r])) {
 			case PAWN:
 			case QUEEN:
 			case ROOK:
 				return 1;
 				break;
 			case BISHOP:
-				if(color(curgame->board[f][r]) != ocolor) {
-					if(bishop_type(f,r) == 1)
+				if (color(curgame->board[f][r]) != ocolor) {
+					if (bishop_type(f, r) == 1)
 						++e_dbishop;
 					else
 						++e_lbishop;
 				} else {
-					if(bishop_type(f,r) == 1)
+					if (bishop_type(f, r) == 1)
 						++o_dbishop;
 					else
 						++o_lbishop;
@@ -1217,7 +1272,7 @@ cgc_has_sufficient(game_t *curgame, int ocolor)
 				break;
 			case KNIGHT:
 				++o_knight;
-				if(o_knight + o_lbishop + o_dbishop >= 2)
+				if (o_knight + o_lbishop + o_dbishop >= 2)
 					return 1;
 				break;
 			}
@@ -1227,24 +1282,23 @@ cgc_has_sufficient(game_t *curgame, int ocolor)
 	o_lbishop -= e_lbishop;
 	o_dbishop -= e_dbishop;
 
-	if(o_lbishop == 1 || o_dbishop == 1)
+	if (o_lbishop == 1 || o_dbishop == 1)
 		return 1;
 
 	return 0;
 }
-	
-static int
-check_knight_moves(piece_t **board, int f, int r)
+
+static int check_knight_moves(piece_t ** board, int f, int r)
 {
 	int diag;
 	int cf, cr;
 
-	
-	for(diag = 0; diag < 8 ; ++diag) {
+
+	for (diag = 0; diag < 8; ++diag) {
 		cf = f;
 		cr = r;
-			
-		switch(diag) {
+
+		switch (diag) {
 		case 0:
 			cf += 2;
 			cr += 1;
@@ -1279,9 +1333,9 @@ check_knight_moves(piece_t **board, int f, int r)
 			break;
 		}
 
-		if(color(board[cf][cr]) == color(board[f][r]))
+		if (color(board[cf][cr]) == color(board[f][r]))
 			break;
-	
+
 		return VALID;
 
 	}
@@ -1296,29 +1350,27 @@ check_knight_moves(piece_t **board, int f, int r)
  * of the king passed and the piece passed aren't the same.
  */
 
-static int
-can_move(struct game *curgame, int f, int r, int kf, int kr)
+static int can_move(struct game *curgame, int f, int r, int kf, int kr)
 {
 	piece_t tmp;
 
 	tmp = curgame->board[f][r];
 	curgame->board[f][r] = EMPTY;
-	
-	if(safe_square(curgame, kf, kr)) {
+
+	if (safe_square(curgame, kf, kr)) {
 		curgame->board[f][r] = tmp;
 		return VALID;
 	}
 
 	curgame->board[f][r] = tmp;
 
-	return INVALID; /* Yeah, we're pinned */
+	return INVALID;	/* Yeah, we're pinned */
 
 }
 
-static int
-onboard(int f, int r)
+static int onboard(int f, int r)
 {
-	if(f > 7 || f < 0 || r > 7 || r < 0)
+	if (f > 7 || f < 0 || r > 7 || r < 0)
 		return INVALID;
 	else
 		return VALID;
@@ -1327,23 +1379,21 @@ onboard(int f, int r)
 
 /* returns 1 for dark bishop, 0 for light */
 
-static int
-bishop_type(int f, int r)
+static int bishop_type(int f, int r)
 {
-	if((f % 2) == 0) {
-		if((r % 2) == 0)
+	if ((f % 2) == 0) {
+		if ((r % 2) == 0)
 			return 1;
 		else
 			return 0;
 	}
-	if((f % 2) == 1) {
-		if((r % 2) == 0)
+	if ((f % 2) == 1) {
+		if ((r % 2) == 0)
 			return 0;
 		else
 			return 1;
 	}
-	
-	return -1;
-	
-}
 
+	return -1;
+
+}
