@@ -4,7 +4,7 @@
  * Project: GGZ Chess game module
  * Date: 09/17/2000
  * Desc: Header for net.c
- * $Id: net.h,v 1.8 2002/09/09 04:51:32 jdorje Exp $
+ * $Id: net.h 6903 2005-01-25 18:57:38Z jdorje $
  *
  * Copyright (C) 2000 Ismael Orenstein.
  *
@@ -23,6 +23,8 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <ggzmod.h>
+
 /* Send time option to server */
 void net_send_time(int time_option);
 
@@ -43,4 +45,4 @@ void net_update_server(int time);
 
 /* All server input will pass through here
  * Then we will filter it and send to game_update */
-void net_handle_input(gpointer data, int fd, GdkInputCondition cond);
+gboolean net_handle_input(GGZMod *mod);
