@@ -28,20 +28,20 @@ extern GtkWidget *dlg_prefs;
 
 
 gboolean
-on_dlg_main_delete_event               (GtkWidget       *widget,
-                                        GdkEvent        *event,
-                                        gpointer         user_data);
+on_dlg_main_delete_event(GtkWidget * widget,
+			 GdkEvent * event, gpointer user_data);
 
 gboolean
-on_draw_area_expose_event              (GtkWidget       *widget,
-                                        GdkEventExpose  *event,
-                                        gpointer         user_data);
+on_draw_area_expose_event(GtkWidget * widget,
+			  GdkEventExpose * event, gpointer user_data);
+gboolean on_draw_area_configure_event(GtkWidget * widget,
+				      GdkEventExpose * event,
+				      gpointer user_data);
 
 gboolean
-on_draw_area_button_press_event        (GtkWidget       *widget,
-                                        GdkEventButton  *event,
-                                        gpointer         user_data);
+on_draw_area_button_press_event(GtkWidget * widget,
+				GdkEventButton * event,
+				gpointer user_data);
 
 void
-on_preferences_menu_activate	       (GtkMenuItem	*menuitem,
-					gpointer	 user_data);
+on_preferences_menu_activate(GtkMenuItem * menuitem, gpointer user_data);
