@@ -366,9 +366,9 @@
 */
 
 // Terrain codes
-#define T_OPEN 0x00   // 0000
-#define T_NULL 0x01   // 0001
-#define T_LAKE 0x02   // 0010
+#define T_OPEN 0x00	// 0000
+#define T_NULL 0x01	// 0001
+#define T_LAKE 0x02	// 0010
 
 // Unit codes
 #define U_FLAG			 0x00	// 0000
@@ -384,12 +384,12 @@
 #define U_GENERAL		 0x0A	// 1010
 #define U_MARSHALL	 0x0B	// 1011
 #define U_UNKNOWN    0x0C	// 1100
-#define U_EMPTY      0x0F // 1111 
+#define U_EMPTY      0x0F	// 1111
 
 // Options codes
-#define O_NAME       0x01 // Name of the map
-#define O_BIN1       0x02 // Binary options pack 1
-#define O_BIN2       0x03 // Binary options pack 2
+#define O_NAME       0x01	// Name of the map
+#define O_BIN1       0x02	// Binary options pack 1
+#define O_BIN2       0x03	// Binary options pack 2
 
 // Binary options code
 #define OPT_OPEN_MAP         (1<<0)
@@ -436,7 +436,7 @@
 #define NEXT(X,Y) (X >= (Y-1) ? 0 : X+1)
 
 // Game states
-#define CBT_STATE_NULL -1 // When he doesn't know his state
+#define CBT_STATE_NULL -1	// When he doesn't know his state
 #define CBT_STATE_INIT 0
 #define CBT_STATE_WAIT 1
 #define CBT_STATE_SETUP 2
@@ -486,7 +486,7 @@
 #define CBT_CHECK_ATTACK_RUSH 3
 
 // Random number
-#define RANDOM(N) (1+(int)((float)N*random()/(RAND_MAX+1.0)))
+#define RANDOM(N) (1+(int)((float)N*rand()/(RAND_MAX+1.0)))
 
 
 
@@ -494,22 +494,24 @@
 
 // Tile struct
 typedef struct tile_struct {
-  unsigned char type;
-  unsigned char unit;
+	unsigned char type;
+	unsigned char unit;
 } tile;
 
 // Game struct
 typedef struct combat_game_struct {
-  tile *map;
-  char width;
-  char height;
-  char **army;
-  char *name;
-  int state;
-  int turn;
-  int number;
-  unsigned long int options;
+	tile *map;
+	char width;
+	char height;
+	char **army;
+	char *name;
+	int state;
+	int turn;
+	int number;
+	unsigned long int options;
 } combat_game;
+extern combat_game cbt_game;
+
 
 // Commom functions
 unsigned char *combat_options_string_write(combat_game *, int for_hash);
