@@ -1,10 +1,10 @@
 /* 
- * File: dlg_about.c
+ * File: dlg_about.h
  * Author: GGZ Development Team
  * Project: GGZ GTK games
  * Date: 10/12/2002
  * Desc: Create the "About" Gtk dialog
- * $Id: dlg_about.h,v 1.1 2002/10/12 19:36:18 jdorje Exp $
+ * $Id: dlg_about.h 6385 2004-11-16 05:21:05Z jdorje $
  *
  * Copyright (C) 2000-2002 Brent Hendricks.
  *
@@ -23,11 +23,12 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
+#include <gtk/gtk.h>
+
 /* Call this function to set the title and content for the
  * about dialog.  Make sure all of the values are translated. */
 void init_dlg_about(const char *title,
-		    const char *header,
-		    const char *about);
+		    const char *header, const char *about);
 
 /* Call this function to show the about dialog. */
 void create_or_raise_dlg_about(void);
