@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Gtk Games (taken from NetSpades)
  * Date: 1/29/99
- * $Id: dlg_exit.h,v 1.3 2002/11/03 07:31:49 jdorje Exp $
+ * $Id: dlg_exit.h 6385 2004-11-16 05:21:05Z jdorje $
  *
  * This fils contains functions for creating and handling the 
  * exit dialog box
@@ -27,4 +27,4 @@
 
 #include <gtk/gtk.h>
 
-void ggz_show_exit_dialog(int can_return, GtkWidget *parent_window);
+void ggz_show_exit_dialog(gboolean can_return);
