@@ -2,7 +2,7 @@
  * File: ggzintl.c
  * Author: GGZ Development Team
  * Project: GGZ Gtk Games
- * $Id: ggzintl.c,v 1.2 2002/04/03 17:18:31 jdorje Exp $
+ * $Id: ggzintl.c 6921 2005-02-05 13:24:19Z josef $
  *
  * This file contains common functions and data for i18n of the
  * gtk-games package.
@@ -32,13 +32,33 @@
 
 #include "ggzintl.h"
 
+#define COMMON_DOMAIN "common"
+
 void ggz_intl_init(const char *modulename)
 {
 #ifdef ENABLE_NLS
+	/* GTK2 always uses UTF-8 so we tell gettext to output its
+	   translations in that. */
 	bindtextdomain(modulename, LOCALEDIR);
+	bindtextdomain(COMMON_DOMAIN, LOCALEDIR);
+	bind_textdomain_codeset(modulename, "UTF-8");
+	bind_textdomain_codeset(COMMON_DOMAIN, "UTF-8");
 	textdomain(modulename);
 	setlocale(LC_ALL, "");
 	ggz_debug("main", _("nls enabled: %s"), modulename);
 #endif
 }
 
+char *ggz_intl_gettext(const char *s)
+{
+#ifdef ENABLE_NLS
+	char *ret;
+	if(!s) return NULL;
+	ret = gettext(s);
+	if(!ggz_strcmp(s, ret)) ret = dgettext(COMMON_DOMAIN, s);
+	return ret;
+#else
+	return s;
+#endif
+}
+
