@@ -4,7 +4,7 @@
  * Project: GGZ Connect the Dots Client
  * Date: 08/14/2000
  * Desc: Main loop and supporting logic
- * $Id: main.c 7273 2005-06-10 12:54:26Z josef $
+ * $Id: main.c 8880 2007-01-09 17:22:14Z josef $
  *
  * Copyright (C) 2000, 2001 Brent Hendricks.
  *
@@ -75,18 +75,9 @@ static int get_sync_info(void);
 int main(int argc, char *argv[])
 {
 	char *filename;
-#ifdef HAVE_WINSOCK_H
-	WSADATA wsa;
-#endif
 
 	initialize_debugging();
 
-#ifdef HAVE_WINSOCK_H
-	if (WSAStartup(MAKEWORD(1, 1), &wsa) != 0) {
-		return 1;
-	}
-#endif
-
 	ggz_intl_init("dots");
 
 	gtk_init(&argc, &argv);
@@ -101,6 +92,7 @@ int main(int argc, char *argv[])
 	game_init();
 
 	mod = init_ggz_gtk(GTK_WINDOW(main_win), game_handle_io);
+	init_chat(mod);
 
 	gtk_main();
 
@@ -155,14 +147,11 @@ static void initialize_about_dialog(void)
 	      "        Gtk+ Client:\n"
 	      "            Rich Gade        <rgade@users.sourceforge.net>\n"
 	      "\n"
-	      "        Windows 9X Client:\n"
-	      "            Doug Hudson  <djh@users.sourceforge.net>\n"
-	      "\n"
 	      "        Game Server:\n"
 	      "            Rich Gade        <rgade@users.sourceforge.net>\n"
 	      "\n"
 	      "Website:\n"
-	      "        http://www.ggzgamingzone.org/games/dots/");
+	      "        http://www.ggzgamingzone.org/gameclients/dots/");
 
 	header = g_strdup_printf(_("GGZ Gaming Zone\n"
 				   "Connect The Dots Version %s"),
@@ -174,7 +163,7 @@ static void initialize_about_dialog(void)
 
 char *opstr[] = { "DOTS_MSG_SEAT", "DOTS_MSG_PLAYERS", "DOTS_MSG_MOVE_H",
 	"DOTS_MSG_MOVE_V", "DOTS_MSG_GAMEOVER", "DOTS_REQ_MOVE",
-	"DOTS_RSP_MOVE", "DOTS_SND_SYNC", "DOTS_MSG_OPTIONS"
+	"DOTS_RSP_MOVE", "DOTS_SND_SYNC", "DOTS_MSG_OPTIONS", "DOTS_REQ_OPTIONS"
 };
 
 static gboolean game_handle_io(GGZMod * mod)
@@ -272,7 +261,7 @@ void game_init(void)
 	l2 = g_object_get_data(G_OBJECT(main_win), "lbl_score1");
 	gtk_label_set_text(GTK_LABEL(l1), _("No Score"));
 	gtk_label_set_text(GTK_LABEL(l2), _("No Score"));
-	gtk_widget_show(main_win);
+	gtk_widget_show_all(main_win);
 	board_init(0, 0);
 
 	game.state = DOTS_STATE_INIT;
@@ -291,8 +280,8 @@ int send_options(void)
 
 static int get_options(void)
 {
-	if (ggz_read_char(game.fd, (char*)&board_width) < 0
-	    || ggz_read_char(game.fd, (char*)&board_height) < 0)
+	if (ggz_read_char(game.fd, &board_width) < 0
+	    || ggz_read_char(game.fd, &board_height) < 0)
 		return -1;
 	return 0;
 }
@@ -321,7 +310,7 @@ static int get_players(void)
 			return -1;
 		if (game.seats[i] != GGZ_SEAT_OPEN) {
 			if (ggz_read_string
-			    (game.fd, (char *)&game.names[i], 17) < 0)
+			    (game.fd, game.names[i], 17) < 0)
 				return -1;
 			temp = g_strdup_printf("   %s   ", game.names[i]);
 			gtk_frame_set_label(GTK_FRAME(frame[i]),
@@ -389,15 +378,15 @@ static int get_sync_info(void)
 		return -1;
 	for (i = 0; i < board_width; i++)
 		for (j = 0; j < board_height - 1; j++)
-			if (ggz_read_char(game.fd, (char*)&vert_board[i][j]) < 0)
+			if (ggz_read_char(game.fd, &vert_board[i][j]) < 0)
 				return -1;
 	for (i = 0; i < board_width - 1; i++)
 		for (j = 0; j < board_height; j++)
-			if (ggz_read_char(game.fd, (char*)&horz_board[i][j]) < 0)
+			if (ggz_read_char(game.fd, &horz_board[i][j]) < 0)
 				return -1;
 	for (i = 0; i < board_width - 1; i++)
 		for (j = 0; j < board_height - 1; j++)
-			if (ggz_read_char(game.fd, (char*)&owners_board[i][j]) <
+			if (ggz_read_char(game.fd, &owners_board[i][j]) <
 			    0)
 				return -1;
 
