@@ -4,7 +4,7 @@
  * Project: GGZCards Server/Client
  * Date: 06/26/2001
  * Desc: Enumerations for the ggzcards client-server protocol
- * $Id: protocol.c 6293 2004-11-07 05:51:47Z jdorje $
+ * $Id: protocol.c 9053 2007-04-17 03:16:36Z jdorje $
  *
  * This just contains the communications protocol information.
  *
@@ -52,12 +52,20 @@ const char *get_server_opcode_name(server_msg_t opcode)
 		return "MSG_GAMEOVER";
 	case MSG_PLAYERS:
 		return "MSG_PLAYERS";
+	case MSG_SCORES:
+		return "MSG_SCORES";
+	case MSG_TRICKS_COUNT:
+		return "MSG_TRICKS_COUNT";
 	case REQ_OPTIONS:
 		return "REQ_OPTIONS";
 	case MSG_NEWHAND:
 		return "MSG_NEWHAND";
+	case MSG_TRUMP:
+		return "MSG_TRUMP";
 	case MSG_HAND:
 		return "MSG_HAND";
+	case MSG_PLAYERS_STATUS:
+		return "MSG_PLAYERS_STATUS";
 	case REQ_PLAY:
 		return "REQ_PLAY";
 	case MSG_BADPLAY:
@@ -72,23 +80,14 @@ const char *get_server_opcode_name(server_msg_t opcode)
 		return "MSG_BID";
 	case MSG_TABLE:
 		return "MSG_TABLE";
-	case MESSAGE_GAME:
-		return "MESSAGE_GAME";
-	}
-	return "[unknown]";
-}
-
-const char *get_game_message_name(game_message_t opcode)
-{
-	switch (opcode) {
-	case GAME_MESSAGE_TEXT:
-		return "GAME_MESSAGE_TEXT";
-	case GAME_MESSAGE_PLAYER:
-		return "GAME_MESSAGE_PLAYER";
-	case GAME_MESSAGE_CARDLIST:
-		return "GAME_MESSAGE_CARDLIST";
-	case GAME_MESSAGE_GAME:
-		return "GAME_MESSAGE_GAME";
+	case MSG_GAME_MESSAGE_TEXT:
+		return "MSG_GAME_MESSAGE_TEXT";
+	case MSG_GAME_MESSAGE_PLAYER:
+		return "MSG_GAME_MESSAGE_PLAYER";
+	case MSG_GAME_MESSAGE_CARDLIST:
+		return "MSG_GAME_MESSAGE_CARDLIST";
+	case MSG_GAME_SPECIFIC:
+		return "MSG_GAME_SPECIFIC";
 	}
 	return "[unknown]";
 }
@@ -108,6 +107,8 @@ const char *get_client_opcode_name(client_msg_t opcode)
 		return "RSP_BID";
 	case REQ_SYNC:
 		return "REQ_SYNC";
+	case REQ_OPEN_HAND:
+		return "REQ_OPEN_HAND";
 	}
 	return "[unknown]";
 }
