@@ -4,7 +4,7 @@
  * Project: GGZCards Client
  * Date: 08/14/2000
  * Desc: Creates the GGZCards main Gtk window
- * $Id: dlg_main.c 6450 2004-12-11 21:57:47Z jdorje $
+ * $Id: dlg_main.c 8924 2007-01-16 00:30:23Z jdorje $
  *
  * Copyright (C) 2000-2002 Brent Hendricks.
  *
@@ -51,12 +51,14 @@ static GtkWidget *create_menus(GtkWidget * window)
 	GtkItemFactoryEntry items[] = {
 		TABLE_MENU,
 		{_("/_Game"), NULL, NULL, 0, "<Branch>"},
-		{_("/Game/Start game"), "<ctrl>N",
+		{GAME_START_GAME, "<ctrl>N",
 		 on_mnu_startgame_activate, 0, NULL},
 #ifdef DEBUG
 		{_("/Game/Force _redraw"), "<ctrl>R",
 		 on_mnu_forceredraw_activate, 0, NULL},
 #endif
+		{_("/Game/Sc_ores"), "<ctrl>O",
+		 on_mnu_scores_activate, 0, NULL},
 		{_("/_Messages"), NULL, NULL, 0, "<Branch>"},
 		{_("/_Options"), NULL, NULL, 0, "<Branch>"},
 		{_("/Options/_Preferences"), "<ctrl>P",
@@ -69,7 +71,7 @@ static GtkWidget *create_menus(GtkWidget * window)
 				   items,
 				   sizeof(items) / sizeof(items[0]));
 
-	set_menu_sensitive(_("<main>/Game/Start game"), FALSE);
+	set_menu_sensitive(GAME_START_GAME, FALSE);
 	set_menu_sensitive(TABLE_CHAT_WINDOW, TRUE);
 
 	return menubar;
