@@ -4,7 +4,7 @@
  * Project: GGZCards Client
  * Date: 08/14/2000
  * Desc: Handles user-interaction with game screen
- * $Id: game.h 6333 2004-11-12 02:27:20Z jdorje $
+ * $Id: game.h 8561 2006-08-31 08:00:24Z jdorje $
  *
  * Copyright (C) 2000-2002 Brent Hendricks.
  *
@@ -133,8 +133,7 @@ gboolean game_handle_ggz(GIOChannel * source, GIOCondition cond,
 			 gpointer data);
 
 /** @brief Handles IO from the server; called any time data is pending. */
-gboolean game_handle_io(GIOChannel * source, GIOCondition cond,
-			gpointer data);
+void game_handle_io(gpointer data, gint source, GdkInputCondition cond);
 
 /** @brief Request a sync from the server, and prepare to receive it. */
 void game_resync(void);
@@ -146,19 +145,25 @@ void game_resync(void);
  */
 
 int game_get_options(int option_cnt,
+		     char **types,
 		     char **descriptions,
 		     int *choice_cnt, int *defaults,
 		     char ***option_choices);
-void game_alert_server(int server_socket_fd);
+void game_alert_server(GGZDataIO * server_dio);
 void game_get_newgame(void);
 void game_alert_newgame(cardset_type_t cardset_type);
 void game_alert_newhand(void);
+void game_alert_trump(void);
 void game_handle_gameover(int num_winners, int *winners);
 void game_alert_player(int player,
 		       GGZSeatType old_status, const char *old_name);
+void game_alert_num_players(int new, int old);
+void game_alert_scores(int hand_num);
+void game_alert_tricks_count(void);
 void game_setup_table(void);
 void game_alert_hand_size(int max_hand_size);
 void game_display_hand(int player);
+void game_alert_players_status(void);
 void game_get_bid(int possible_bids,
 		  bid_t * bid_choices, char **bid_texts, char **bid_descs);
 void game_get_play(int play_hand, int num_valid_cards,
@@ -172,6 +177,6 @@ void game_set_text_message(const char *mark, const char *message);
 void game_set_cardlist_message(const char *mark, int *lengths,
 			       card_t ** cardlist);
 void game_set_player_message(int player, const char *message);
-int game_handle_game_message(int fd, const char *game, int size);
+void game_handle_game_message(GGZDataIO * dio, const char *game);
 
 #endif /* __GAME_H__ */
