@@ -32,12 +32,8 @@ typedef struct playArea_t {
 	GtkWidget *field;
 	GtkWidget *hand;
 	GdkPixmap *handBuf;
-#ifdef GTK2
 	GdkPixbuf *cards;
-#else
-	GdkPixmap *cards;
-#endif
-#if 0 /* Card backs aren't used */
+#if 0				/* Card backs aren't used */
 	GdkPixmap *cardbacks;
 #endif
 	GtkWidget *bidButton;
